/*
Copyright 2008  Nathan Bradshaw nathanlbradshaw@gmail.com

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) version 3, or any
later version accepted by the membership of KDE e.V. (or its
successor approved by the membership of KDE e.V.), which shall
act as a proxy defined in Section 6 of version 3 of the license.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public 
License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/


#ifndef HTTPQUERY_H
#define HTTPQUERY_H


#include <QtCore/QObject>
#include "query.h"

#include <KUrl>

#include "servicemodel_export.h"

//forward decs
class KJob;
class QByteArray;
namespace KIO {
   class Job;
}

// Namespace
namespace ServiceModel { 

class HttpQueryPrivate;

// Class HttpQuery
class SERVICEMODEL_EXPORT HttpQuery : public Query {
   
   Q_OBJECT
   
   public:
      HttpQuery (Service *service, QObject *parent = 0);
      virtual ~HttpQuery();
      
      /** URL called by query */
      KUrl url();
      
      /** Allow for the addition of directories to the base url provided by the service
      *
      * Use this function in instances where the base url provided by the service requires additional directory entries after the base
      * in order to perform a valid look up. For example in a REST style URL the base would define the start of the web service, additional
      * directory paths would define the query to perform and parameters would provide the query terms
      *
      */
      void addDirectoryToUrl(QString directory);
      
      /** should the path finish with a trailing slash */
      void setTrailingSlash(bool trailingSlash);
      
      /** execute the query */
      void execute ();
      
      /** return the response the query generated */
      ServiceModel::Response* response ();
      
   protected slots :
      void receiveData(KIO::Job*, const QByteArray data);
      
   protected:
      /** dynamic pointer for private class */
      HttpQueryPrivate * const d_ptr;
      
      HttpQuery(HttpQueryPrivate &dd, Service *service, QObject *parent);
      
   private:
      Q_DECLARE_PRIVATE(HttpQuery)
      
};
} 
#endif //HTTPQUERY_H

