/*  This file is part of the KDE project
    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef MIXERENUMCONTROL_P_H
#define MIXERENUMCONTROL_P_H

#include "mixercontrol_p.h"
#include "mixerenumcontrol.h"
#include "defs_p.h"

namespace Phonon
{
namespace Mixer
{

class MixerEnumControlSharedData : public MixerControlSharedData
{
    friend class MixerEnumControl;
    friend class MixerEnumControlPrivate;
    Q_OBJECT
    public:
        MixerEnumControlSharedData(const MixerSharedData::Ptr &mixer, const AlsaElementId &id, MixerEnumControl::Category type);
        typedef QExplicitlySharedDataPointer<MixerEnumControlSharedData> Ptr;

        virtual void valueChangeEvent();

    Q_SIGNALS:
        void currentIndexChanged(int);
        void currentIndexChanged(const QString &);

    private Q_SLOTS:
        void setCurrentIndex(const QString &);
        void setCurrentIndex(int);

    private:
        virtual void init() {}
        QStringList options() const;
        QString currentOption() const;
        int currentIndex() const;

        MixerEnumControl::Category m_category;
        QStringList m_options;
};

class MixerEnumControlPrivate : public MixerControlPrivate
{
    Q_DECLARE_PUBLIC(MixerEnumControl)
    K_DECLARE_SHARED(MixerEnumControl)
    public:
        MixerEnumControlPrivate(MixerEnumControlSharedData *s) : MixerControlPrivate(MixerControlSharedData::Ptr(s)) {}
};

} // namespace Mixer
} // namespace Phonon

#endif // MIXERENUMCONTROL_P_H
