/*  This file is part of the KDE project
    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License version 2 as published by the Free Software Foundation.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.

*/

#ifndef MIXERTOGGLECONTROL_P_H
#define MIXERTOGGLECONTROL_P_H

#include "mixercontrol_p.h"
#include "mixertogglecontrol.h"
#include "defs_p.h"

namespace Phonon
{
namespace Mixer
{

class MixerToggleControlSharedData : public MixerControlSharedData
{
    friend class MixerToggleControl;
    Q_OBJECT
    public:
        MixerToggleControlSharedData(const MixerSharedData::Ptr &mixer, const AlsaElementId &id, MixerToggleControl::Category category);
        typedef QExplicitlySharedDataPointer<MixerToggleControlSharedData> Ptr;

        virtual void valueChangeEvent();

    Q_SIGNALS:
        void toggled(bool);

    public Q_SLOTS:
        void setChecked(bool);

    private:
        virtual void init() {}
        bool isChecked() const;

        MixerToggleControl::Category m_category;
};

class MixerToggleControlPrivate : public MixerControlPrivate
{
    Q_DECLARE_PUBLIC(MixerToggleControl)
    K_DECLARE_SHARED(MixerToggleControl)
    public:
        MixerToggleControlPrivate(MixerToggleControlSharedData *s) : MixerControlPrivate(MixerControlSharedData::Ptr(s)) {}
};

} // namespace Mixer
} // namespace Phonon

#endif // MIXERTOGGLECONTROL_P_H
